;; Generated package description from greader.el  -*- no-byte-compile: t -*-
(define-package "greader" "0.7.0" "gnamù reader, send buffer contents to a speech engine." '((emacs "25")) :commit "c4caf70e405d9c80a388e00e014f8aa3f72a90e6" :url "https://elpa.gnu.org/packages/greader.html" :authors '(("Michelangelo Rodriguez" . "michelangelo.rodriguez@gmail.com")) :maintainer '("Michelangelo Rodriguez" . "michelangelo.rodriguez@gmail.com") :keywords '("tools" "accessibility"))
